==> zio-aws-ec2_2.13-5.17.104.10-sources.jar: zio/aws/ec2/model/ClientVpnEndpointAttributeStatus.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ClientVpnEndpointAttributeStatus(
    code: Option[zio.aws.ec2.model.ClientVpnEndpointAttributeStatusCode] = None,
    message: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ClientVpnEndpointAttributeStatus = {
    import ClientVpnEndpointAttributeStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ClientVpnEndpointAttributeStatus
      .builder()
      .optionallyWith(code.map(value => value.unwrap))(_.code)
      .optionallyWith(message.map(value => value: java.lang.String))(_.message)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ClientVpnEndpointAttributeStatus.ReadOnly =
    zio.aws.ec2.model.ClientVpnEndpointAttributeStatus.wrap(buildAwsValue())
}
object ClientVpnEndpointAttributeStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ClientVpnEndpointAttributeStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ClientVpnEndpointAttributeStatus =
      zio.aws.ec2.model.ClientVpnEndpointAttributeStatus(
        code.map(value => value),
        message.map(value => value)
      )
    def code: Option[zio.aws.ec2.model.ClientVpnEndpointAttributeStatusCode]
    def message: Option[String]
    def getCode: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.ClientVpnEndpointAttributeStatusCode
    ] = AwsError.unwrapOptionField("code", code)
    def getMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ClientVpnEndpointAttributeStatus
  ) extends zio.aws.ec2.model.ClientVpnEndpointAttributeStatus.ReadOnly {
    override val code
        : Option[zio.aws.ec2.model.ClientVpnEndpointAttributeStatusCode] = scala
      .Option(impl.code())
      .map(value =>
        zio.aws.ec2.model.ClientVpnEndpointAttributeStatusCode.wrap(value)
      )
    override val message: Option[String] =
      scala.Option(impl.message()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ClientVpnEndpointAttributeStatus
  ): zio.aws.ec2.model.ClientVpnEndpointAttributeStatus.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-6.20.103.1-sources.jar: zio/aws/ec2/model/ClientVpnEndpointAttributeStatus.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ClientVpnEndpointAttributeStatus(
    code: Optional[zio.aws.ec2.model.ClientVpnEndpointAttributeStatusCode] =
      Optional.Absent,
    message: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ClientVpnEndpointAttributeStatus = {
    import ClientVpnEndpointAttributeStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ClientVpnEndpointAttributeStatus
      .builder()
      .optionallyWith(code.map(value => value.unwrap))(_.code)
      .optionallyWith(message.map(value => value: java.lang.String))(_.message)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ClientVpnEndpointAttributeStatus.ReadOnly =
    zio.aws.ec2.model.ClientVpnEndpointAttributeStatus.wrap(buildAwsValue())
}
object ClientVpnEndpointAttributeStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ClientVpnEndpointAttributeStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ClientVpnEndpointAttributeStatus =
      zio.aws.ec2.model.ClientVpnEndpointAttributeStatus(
        code.map(value => value),
        message.map(value => value)
      )
    def code: Optional[zio.aws.ec2.model.ClientVpnEndpointAttributeStatusCode]
    def message: Optional[String]
    def getCode: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.ClientVpnEndpointAttributeStatusCode
    ] = AwsError.unwrapOptionField("code", code)
    def getMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ClientVpnEndpointAttributeStatus
  ) extends zio.aws.ec2.model.ClientVpnEndpointAttributeStatus.ReadOnly {
    override val code
        : Optional[zio.aws.ec2.model.ClientVpnEndpointAttributeStatusCode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.code())
        .map(value =>
          zio.aws.ec2.model.ClientVpnEndpointAttributeStatusCode.wrap(value)
        )
    override val message: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.message())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ClientVpnEndpointAttributeStatus
  ): zio.aws.ec2.model.ClientVpnEndpointAttributeStatus.ReadOnly = new Wrapper(
    impl
  )
}
